@@ -5,7 +5,8 @@ import (
 	"os"
 	"os/exec"
 	"strconv"
-	"strings"
+
+	log "github.com/sirupsen/logrus"
 )
 
 var runner commandRunner = &defaultCommandRunner{}
@@ -16,16 +17,6 @@ var Settings = struct {
 	Verbose bool
 }{}
 
-// DryRun toggles the state of the command runner. If true, commands are only printed to the console
-// without execution.
-func DryRun(d bool) {
-	if d {
-		runner = dryRunCommandRunner{}
-		return
-	}
-	runner = &defaultCommandRunner{}
-}
-
 // Command creates a new command.
 func Command(command string, args ...string) *exec.Cmd { return runner.Command(command, args...) }
 
@@ -47,6 +38,9 @@ func (d defaultCommandRunner) Command(command string, args ...string) *exec.Cmd
 	cmd := exec.Command(command, args...)
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
+
+	log.Trace("cmd ", quotedArgs(cmd.Args))
+
 	return cmd
 }
 
@@ -55,29 +49,18 @@ func (d defaultCommandRunner) CommandInteractive(command string, args ...string)
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
+
+	log.Trace("cmd int ", quotedArgs(cmd.Args))
+
 	return cmd
 }
 
-var _ commandRunner = (*dryRunCommandRunner)(nil)
-
-type dryRunCommandRunner struct{}
-
-func (d dryRunCommandRunner) Command(command string, args ...string) *exec.Cmd {
-	d.printArgs("run:", command, args...)
-	return exec.Command("echo")
-}
-
-func (d dryRunCommandRunner) CommandInteractive(command string, args ...string) *exec.Cmd {
-	d.printArgs("interactive run:", command, args...)
-	return exec.Command("echo")
-}
-func (d dryRunCommandRunner) printArgs(prefix, command string, args ...string) {
-	var str []string
-	str = append(str, prefix, strconv.Quote(command))
-	for _, arg := range args {
-		str = append(str, strconv.Quote(arg))
+func quotedArgs(args []string) string {
+	var q []string
+	for _, s := range args {
+		q = append(q, strconv.Quote(s))
 	}
-	fmt.Println(strings.Join(str, " "))
+	return fmt.Sprintf("%v", q)
 }
 
 // Prompt prompts for input with a question. It returns true only if answer is y or Y.
